# Description

A compilation of 1600+ tasks phrased as natural instructions.
The original task collection can be found at:
https://github.com/allenai/natural-instructions.
No preprocessing or changes were made to this original version.


Note that users of this task collection should consult the underlying
licenses of the contained datasets, and cite them accordingly.